@@ -75,23 +75,18 @@ ps_users <- function() {
   d
 }
 
-#' Number of logical or phyisical CPUs
+#' Number of logical or physical CPUs
 #'
 #' If cannot be determined, it returns `NA`. It also returns `NA` on older
 #' Windows systems, e.g. Vista or older and Windows Server 2008 or older.
-#' 
+#'
 #' @param logical Whether to count logical CPUs.
 #' @return Integer scalar.
-#' 
-#' @export
 #'
-#' @rawRd
-#' \section{Examples}{
-#' \Sexpr[stage=install,strip.white=FALSE,results=rd]{ps:::decorate_examples('
+#' @export
+#' @examplesIf ps::ps_is_supported() && ! ps:::is_cran_check()
 #' ps_cpu_count(logical = TRUE)
 #' ps_cpu_count(logical = FALSE)
-#' ')}
-#' }
 
 ps_cpu_count <- function(logical = TRUE) {
   assert_flag(logical)
@@ -101,7 +96,7 @@ ps_cpu_count <- function(logical = TRUE) {
  ps_cpu_count_logical <- function() {
    .Call(ps__cpu_count_logical)
  }
- 
+
 ps_cpu_count_physical <- function() {
   if (ps_os_type()[["LINUX"]]) {
     ps_cpu_count_physical_linux()
@@ -109,3 +104,41 @@ ps_cpu_count_physical <- function() {
     .Call(ps__cpu_count_physical)
   }
 }
+
+#' Query the size of the current terminal
+#'
+#' If the standard output of the current R process is not a terminal,
+#' e.g. because it is redirected to a file, or the R process is running in
+#' a GUI, then it will throw an error. You need to handle this error if
+#' you want to use this function in a package.
+#'
+#' If an error happens, the error message is different depending on
+#' what type of device the standard output is. Some common error messages
+#' are:
+#' * "Inappropriate ioctl for device."
+#' * "Operation not supported on socket."
+#' * "Operation not supported by device."
+#'
+#' Whatever the error message, `ps_tty_size` always fails with an error of
+#' class `ps_unknown_tty_size`, which you can catch.
+#'
+#' @export
+#' @examples
+#' # An example that falls back to the 'width' option
+#' tryCatch(
+#'   ps_tty_size(),
+#'   ps_unknown_tty_size = function(err) {
+#'     c(width = getOption("width"), height = NA_integer_)
+#'   }
+#' )
+
+ps_tty_size <- function() {
+  tryCatch(
+    ret <- .Call(ps__tty_size),
+    error = function(err) {
+      class(err) <- c("ps_unknown_tty_size", class(err))
+      stop(err)
+    }
+  )
+  c(width = ret[1], height = ret[2])
+}
