@@ -55,7 +55,12 @@ SEXP ps__pids() { return ps__dummy("ps_pids"); }
 SEXP ps__boot_time() { return ps__dummy("ps_boot_time"); }
 SEXP ps__cpu_count_logical()  { return ps__dummy("ps_cpu_count"); }
 SEXP ps__cpu_count_physical() { return ps__dummy("ps_cpu_count"); }
-SEXP ps__users() { ps__users("ps_users"); }
+SEXP ps__users() { ps__dummy("ps_users"); }
+SEXP ps__tty_size() { ps__dummy("ps_tty_size"); }
+SEXP ps__disk_partitions(SEXP x) { ps__dummy("ps_disk_partitions"); }
+SEXP ps__disk_usage() { ps__dummy("ps_disk_usage"); }
+SEXP ps__system_memory() { ps__dummy("ps_system_memory"); }
+SEXP ps__system_swap() { ps__dummy("ps_system_swap"); }
 
 SEXP psll_handle(SEXP x, SEXP y) { return ps__dummy("ps_handle"); }
 SEXP psll_format(SEXP x) { return ps__dummy("ps_format"); }
@@ -65,7 +70,7 @@ SEXP psll_is_running(SEXP x) { return ps__dummy("ps_is_running"); }
 SEXP psll_name(SEXP x) { return ps__dummy("ps_name"); }
 SEXP psll_exe(SEXP x) { return ps__dummy("ps_exe"); }
 SEXP psll_cmdline(SEXP x) { return ps__dummy("ps_cmdline"); }
-SEXP psll_status(SEPX x) { return ps__dummy("ps_status"); }
+SEXP psll_status(SEXP x) { return ps__dummy("ps_status"); }
 SEXP psll_username(SEXP x) { return ps__dummy("ps_username"); }
 SEXP psll_cwd(SEXP x) { return ps__dummy("ps_cwd"); }
 SEXP psll_uids(SEXP x) { return ps__dummy("ps_uids"); }
@@ -79,11 +84,13 @@ SEXP psll_send_signal(SEXP x, SEXP y) { return ps__dummy("ps_send_signal"); }
 SEXP psll_suspend(SEXP x) { return ps__dummy("ps_suspend"); }
 SEXP psll_resume(SEXP x) { return ps__dummy("ps_resume"); }
 SEXP psll_terminate(SEXP x) { return ps__dummy("ps_terminate"); }
-SEXP psll_kill(SEPX x) { return ps__dummy("ps_kill"); }
+SEXP psll_kill(SEXP x) { return ps__dummy("ps_kill"); }
 SEXP psll_num_fds(SEXP x) { return ps__dummy("ps_num_fds"); }
 SEXP psll_open_files(SEXP x) { return ps__dummy("ps_open_files"); }
 SEXP psll_interrupt(SEXP x, SEXP y, SEXP z) { return ps__dummy("ps_interrupt"); }
 SEXP psll_connections(SEXP x) { return ps__dummy("ps_connections"); }
+SEXP psll_get_nice(SEXP x) { return ps__dummy("ps_get_nice"); }
+SEXP psll_set_nice(SEXP x, SEXP y) { return ps__dummy("ps_set_nice"); }
 
 SEXP ps__init(SEXP x, SEXP y) { return R_NilValue; /* this needs to run to load package */ }
 SEXP ps__kill_if_env(SEXP x, SEXP y, SEXP z, SEXP a) { return ps__dummy("ps__kill_if_env"); }
